@@ -20,11 +20,11 @@
 
 #include "kgameprocess.h"
 
-#include <krandomsequence.h>
+#include <KRandomSequence>
 
-#include <qbuffer.h>
+#include <QBuffer>
 #include <QDataStream>
-#include <QtCore/QFile>
+#include <QFile>
 
 #include <assert.h>
 #include <stdio.h>
@@ -75,10 +75,8 @@ KGameProcess::~KGameProcess()
 }
 
 
-bool KGameProcess::exec(int argc, char *argv[])
+bool KGameProcess::exec()
 {
-  // Get id and cookie, ... from command line
-  processArgs(argc,argv);
   do
   {
     mMessageIO->exec();
@@ -112,23 +110,6 @@ void KGameProcess::sendMessage(QDataStream &stream,int msgid,quint32 receiver)
   sendSystemMessage(stream,msgid+KGameMessage::IdUser,receiver);
 }
 
-void KGameProcess::processArgs(int argc, char *argv[])
-{
-  int v=0;
-  if (argc>2)
-  {
-    v=atoi(argv[2]);
-    //qCDebug(KFOURINLINE_LOG) << "cookie (unused) " << v;
-  }
-  if (argc>1)
-  {
-    v=atoi(argv[1]);
-    //qCDebug(KFOURINLINE_LOG) << "id (unused) " << v;
-  }
-  fprintf(stderr,"KGameProcess::processArgs \n");
-  fflush(stderr);
-}
-
 void KGameProcess::receivedMessage(const QByteArray& receiveBuffer)
 {
  QDataStream stream(receiveBuffer);
